======
TODO's
======


* If a template type is not registered in Compiler.mimetypes:
  * warn via log.warn()
  * force 'precompile' to false

* Support non-asset-specs in Compiler.render()
  (maybe Compiler.render_files(), etc, ala lessc.Compiler.render_*()?)
